@@ -7,5 +7,7 @@ __copyright__ = 'Copyright 2012 John Krauss'
 
 from .api import init
 from .utils import signature, global_config
-from .exceptions import NotJsonError, InvalidKeyError, DifferentRepoError, NoGlobalSettingError
+from .exceptions import (
+    NotJsonError, InvalidKeyError, DifferentRepoError, NoGlobalSettingError,
+    StagedDataError )
 from .constants import GIT_SORT_NONE, GIT_SORT_TOPOLOGICAL, GIT_SORT_TIME, GIT_SORT_REVERSE
